@@ -11,17 +11,23 @@ use strict;
 use Carp;
 use Data::Table::Text qw(:all);
 use Data::Dump qw(dump);
-our $VERSION = 2017.114;
+our $VERSION = 2017.115;
 
 saveToS3('BinaryHeapArray') if 0;
 
 #1 Methods
-sub new()                                                                       # Create a new binary heap Array
- {return bless {}
+sub new()                                                                       # Create a new binary heap array
+ {return bless []
  } # new
 
-sub subarray             {$_[0]{subarray} //= []}                               ## An array, always a power of 2 wide, containing sub arrays which contain the caller's data or slots which are empty, each of the sub arrays is a power of 2 wide which depends on its position in the array of sub arrays so that all of these arrays make good use of memory provided via a buddy memory allocation system to construct the binary heap array
-sub inuse :lvalue {my $v; $_[0]{inuse}    //= $v}                               ## A vec of bits, the same width as subarray where each bit tells us whether the corresponding sub array is in use or not.
+sub subarray                                                                    ## An array, always a power of 2 wide, containing sub arrays which contain the caller's data or slots which are empty, each of the sub arrays is a power of 2 wide which depends on its position in the array of sub arrays so that all of these arrays make good use of memory provided via a buddy memory allocation system to construct the binary heap array
+ {no overloading;
+  $_[0][0] //= []                                                               # Field 1
+ }
+sub inuse :lvalue                                                               ## A vec() of bits, the same width as subarray where each bit tells us whether the corresponding sub array is in use or not.
+ {no overloading;
+  $_[0][1] //= my($v)                                                           # Field 2
+ }
 
 sub at($$) :lvalue                                                              # Address the element at a specified index so that it can get set or got
  {my ($array, $index) = @_;                                                     # Array, index of element
